@@ -341,12 +341,12 @@ static void outPrologue(int nPages)
   outPdf("%PDF-1.3\n");
   /* out binary for transfer program */
   linebuf[0] = '%';
-  linebuf[1] = 129;
-  linebuf[2] = 130;
-  linebuf[3] = 131;
-  linebuf[4] = 132;
+  linebuf[1] = (char)129;
+  linebuf[2] = (char)130;
+  linebuf[3] = (char)131;
+  linebuf[4] = (char)132;
   linebuf[5] = '\n';
-  linebuf[6] = 0;
+  linebuf[6] = (char)0;
   outPdf(linebuf);
   outPdf("% This file was generated by imagetopdf\n");
 
@@ -735,7 +735,10 @@ main(int  argc,				/* I - Number of command-line arguments */
             filename);
 
     while ((bytes = fread(buffer, 1, sizeof(buffer), stdin)) > 0)
-      write(fd, buffer, bytes);
+      if (write(fd, buffer, bytes) == -1)
+	fprintf(stderr,
+		"DEBUG: imagetopdf - write error on temp print file \"%s\"\n",
+		filename);
 
     close(fd);
   }
